@@ -15,7 +15,7 @@ class LoginHistory(BaseModel):
 class User(BaseModel):
     id: int
     email: str
-    password: str
+    password: str = None
     clientid: int
     uuid: str
     permissions: List[str] #List[Role]
@@ -49,4 +49,4 @@ class User(BaseModel):
 
 
 class Users(BaseModel):
-    users: List[User] = []
\ No newline at end of file
+    users: List[User] = []
